@@ -14,6 +14,7 @@ from Downloader import Downloader
 from PyQt4.QtCore import *
 import Utils
 import os
+import time
 
 APP_KEY = 'de5f447222ac49189edc36cd061806c6'
 APP_SECRET = '7ba914334cfc0ef56271de89be36cdb0'
@@ -47,7 +48,7 @@ class UpdaterQQ(QThread):
         self.auth.setToken(username, password)
         self.api = API(self.auth, parser=JSONParser())
 
-    def initialize(self, accountId,timelineType,pageflat,pagetime,countnum,downpic):
+    def initialize(self, accountId,timelineType,pageflat,pagetime,countnum,downpic, rootid=None):
         self.logger.debug("UpdaterQQ:initialize")
         self.stopped = False
         self.accountId=accountId
@@ -58,6 +59,7 @@ class UpdaterQQ(QThread):
         self.downpic=downpic
         self.completed = False
         self.timeline = []
+        self.rootid = rootid
 
 
     def stop(self):
@@ -78,7 +80,7 @@ class UpdaterQQ(QThread):
     def run(self):
         self.logger.debug("run")
         try:
-            self.update_timeline(self.pageflat,self.pagetime,self.countnum)
+            self.update_timeline(self.pageflat,self.pagetime,self.countnum,self.rootid)
         except WeibopError,we:
             self.completed=False
             self.emit(SIGNAL("finished(bool)"),self.completed)
@@ -86,9 +88,10 @@ class UpdaterQQ(QThread):
         self.stop()
 
 
-    def update_timeline(self,pageFlag=0,pagetime=0,countNum=10):
+    def update_timeline(self,pageFlag=0,pagetime=0,countNum=10, rootid=None):
         self.logger.debug("update_timeline")
         param={}
+        param1={}
         param["type"]=0
         param["contenttype"]=7
         param["reqnum"]=countNum
@@ -103,7 +106,16 @@ class UpdaterQQ(QThread):
         elif self.timelineType==Utils.TIMELINE_TYPE_MENTIONS:
             timeline = self.api.timeline.mentions(**param)
         elif self.timelineType==Utils.TIMELINE_TYPE_COMMENTS:
+            param["type"]=80
             timeline = self.api.timeline.broadcast(**param)
+        elif self.timelineType==Utils.TIMELINE_TYPE_ST_COMMENTS:
+            param1["twitterid"]=0
+            param1["reqnum"]=countNum
+            param1["pageflag"]=pageFlag
+            param1["pagetime"]=pagetime            
+            param1["rootid"]= rootid           
+            param1["flag"]=1
+            timeline = self.api.tweet.retweetlist(**param1)
         elif self.timelineType==Utils.TIMELINE_TYPE_FAVOUR:
             param={}
             param["source"]=APP_KEY
@@ -112,6 +124,12 @@ class UpdaterQQ(QThread):
 	
         if timeline['data']!=None:
             for line in timeline['data']['info']:
+                #print "!!!!!!!!!!!!!!!!!!"
+                
+                #print line["id"]
+                #print line["text"]
+                #print line["origtext"]
+                #print "------------------"
                 status=Utils.build_a_status_from_obj_qq(line,self.accountId)
                 
                 self.timeline.append(status)
@@ -155,7 +173,10 @@ class UpdaterQQ(QThread):
                                 self.writer.write_to(picFilename, picSource)
                 
         self.completed = True
-        self.emit(SIGNAL("finished(bool)"),self.completed)
+        if self.timelineType!=Utils.TIMELINE_TYPE_ST_COMMENTS:   
+            self.emit(SIGNAL("finished(bool)"),self.completed)
+        else:
+            self.emit(SIGNAL("cm_finished(bool)"),self.completed)
         self.logger.info("update completed!")
 
         
@@ -252,9 +273,26 @@ class SenderQQ(QThread):
             param["reid"]=param["id"]
             status=self.api.tweet.retweet(**param)
         elif timelineType==Utils.TIMELINE_TYPE_COMMENTS:
-            #comment
-            self.logger.debug("send a comment")
-            status=self.api.tweet.comment(**param)
+            #rt it first
+            try:
+                if param["without_mention"]==2:
+                    param["reid"]=param["id"]
+                    print "#rt it first"
+                    status=self.api.tweet.retweet(**param)
+                print "and comment it"   
+                time.sleep(5)
+                status=self.api.tweet.comment(**param)
+            except KeyError,ae:
+                pass
+                
+            try:
+                param["reid"]=param["cid"]
+                status=self.api.tweet.reply(**param)
+            except KeyError,ae:
+                #comment
+                self.logger.debug("send a comment")
+                print "comment it only"    
+                status=self.api.tweet.comment(**param)
         elif timelineType==Utils.TIMELINE_TYPE_DM:
             #dm
             self.logger.debug("send a dm")
